
% Plot CMS and related spectra
% Jack Baker
% 4/5/2010

% This simple script performs the Conditional Mean Spectrum calculation 

clear; close all; clc

% target event
T_star = 1; % period at which PSHA was performed (the rest of the CMS is conditioned on this)
M = 7; % magnitude
R = 10; % distance (km)
epsilon = 2; % epsilon at T_star
fault_type = 0; % reverse fault
Vs30 = 760; % site conditions, as measured by Vs30

% Ground motion prediction model calcs
periods = logspace(-2,1,100); % periods of interest
for i=1:length(periods)
    [median_sa(i), sigma(i)] = BA_2008_nga (M, periods(i), R, 1, Vs30); % median of Sa and standard deviation of lnSa
    rho(i) = baker_jayaram_correlation(T_star, periods(i)); % correlation coefficient with T_star
end
CMS = exp( log(median_sa) + epsilon.* rho .* sigma); % CMS, conditioned on T_star
CMS_sigma = sigma .* sqrt(1-rho.^2); % Conditional standard deviation of lnSa

% plot spectra
figure
loglog(periods, median_sa, '-k', 'linewidth', 1)
hold on
plot(periods, CMS, '-.r', 'linewidth', 2)
plot(periods, exp(log(CMS)+CMS_sigma), '-r', 'linewidth', 1)
plot(periods, exp(log(CMS)-CMS_sigma), '-r', 'linewidth', 1)
plot([T_star T_star], [0.01 2], ':k', 'linewidth', 0.5)
[legh, objh] = legend(['Median Sa, given M = ' num2str(M) ', R = ' num2str(R) ' km'], ...
    ['CMS, given M = ' num2str(M) ', R = ' num2str(R) 'km, \epsilon(' num2str(T_star) 's) = ' num2str(epsilon)], ...
    'CMS +/- \sigma', 3);
set(legh, 'FontSize', 12);
hx = xlabel('Period (s)', 'FontSize', 14);
hy = ylabel('Spectral Acceleration (g)', 'FontSize', 14);
axis([0.01 10 0 2])
set(gca, 'FontSize', 12);

